# Extrapolated Tree (ExtraTree)

**ExtraTree** implements extrapolated tree methods for regression, classification and density estimation based on pure python. 

## Contents

- [Installation](#Installation)


## Installation

### Via PypI

```bash
pip install ExtraTree
```

### Via GitHub

```bash
pip install git+https://github.com/Karlmyh/ExtraTree.git
```


### Mannul Install
  > 
```bash
git clone git@github.com:Karlmyh/ExtraTree.git
cd ExtraTree 
python setup.py install
```
